summaryrefslogtreecommitdiffstats
path: root/apps/files_external/js/mountsfilelist.js
diff options
context:
space:
mode:
Diffstat (limited to 'apps/files_external/js/mountsfilelist.js')
-rw-r--r--apps/files_external/js/mountsfilelist.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/apps/files_external/js/mountsfilelist.js b/apps/files_external/js/mountsfilelist.js
index c5817a916f6..58cd356ccff 100644
--- a/apps/files_external/js/mountsfilelist.js
+++ b/apps/files_external/js/mountsfilelist.js
@@ -18,7 +18,7 @@
* Displays a list of mount points visible
* for the current user.
*
* @param $el container element with existing markup for the #controls
* and a table
* @param [options] map of options, see other parameters
**/
@@ -65,8 +65,8 @@
var dir = this.getCurrentDirectory();
if (dir === '/') {
// root has special permissions
- this.$el.find('#emptycontent').toggleClass('hidden', !this.isEmpty);
- this.$el.find('#filestable thead th').toggleClass('hidden', this.isEmpty);
+ this.$el.find('.emptyfilelist.emptycontent').toggleClass('hidden', !this.isEmpty);
+ this.$el.find('.files-filestable thead th').toggleClass('hidden', this.isEmpty);
}
else {
OCA.Files.FileList.prototype.updateEmptyContent.apply(this, arguments);
@@ -18,7 +18,7 @@
* for the current user.
*
- * @param $el container element with existing markup for the #controls
+ * @param $el container element with existing markup for the .files-controls
* and a table
* @param [options] map of options, see other parameters